bgpwtf: move tests from eoip to gretap

This removes our dependency on a userspace EoIP implementation that is
mildly broken, and that doesn't build correctly on new gcc versions.

Change-Id: I404c79585336ebaf3bc1761b54ee2433f0841324
diff --git a/bgpwtf/machines/tests/edge01-waw.nix b/bgpwtf/machines/tests/edge01-waw.nix
index 535418f..1d724e1 100644
--- a/bgpwtf/machines/tests/edge01-waw.nix
+++ b/bgpwtf/machines/tests/edge01-waw.nix
@@ -5,9 +5,9 @@
 # - bgpspeaker, which simulates bgp upstreams
 # - customs, which simulates customs.hackerspace.pl.
 #
 # We use EoIP to build up virtual ethernet links between the machines, and
 # to run VLANs on that. We don't just use plain 'vlans' from NixOS tests as
 # we actually want to run 802.1q ourselves from the edge01 config.
 #
 # Everything else is pretty much straightforward. Bring up everything, ping
 # stuff. We don't really test much else than internet routing.
@@ -31,19 +31,15 @@
   virtualisation.memorySize = 1024;
   virtualisation.vlans = [ 1 ];
   imports = [
-    ../modules/eoip.nix
+    ../modules/gretap.nix
   ];
 
-  hscloud.eoip.interfaces."nnet" = {
+  hscloud.gretap.interfaces."nnet" = {
     parent = "eth1";
     localV4 = "192.168.1.3";
     remoteV4 = "192.168.1.2";
     id = 100;
   };
-  networking.interfaces."nnet" = {
-    virtual = true;
-    virtualType = "tap";
-  };
   networking.vlans = {
     "vl-globalmix" = { interface = "nnet"; id = 466; };
   };
@@ -142,27 +138,20 @@
     dut = { config, pkgs, ... }: {
       imports = [
         ../edge01.waw.bgp.wtf.nix
-        ../modules/eoip.nix
+        ../modules/gretap.nix
       ];
       virtualisation.memorySize = 1024;
       virtualisation.vlans = [
         1 2
       ];
 
-      hscloud.eoip.interfaces = {
+      hscloud.gretap.interfaces = {
         "e1-nnet" = { parent = "eth1"; localV4 = "192.168.1.2"; remoteV4 = "192.168.1.3"; id = 100; };
         "e2-customs" = { parent = "eth2"; localV4 = "192.168.2.2"; remoteV4 = "192.168.2.1"; id = 200; };
         "e3-mgmt" = { parent = "eth2"; localV4 = "192.168.2.2"; remoteV4 = "192.168.2.111"; id = 300; }; # not connected
         "e4-oob" = { parent = "eth2"; localV4 = "192.168.2.2"; remoteV4 = "192.168.2.112"; id = 400; }; # not connected
         "e7-dcsw" = { parent = "eth2"; localV4 = "192.168.2.2"; remoteV4 = "192.168.2.113"; id = 500; }; # not connected
       };
-      networking.interfaces = {
-        "e1-nnet" = { virtual = true; virtualType = "tap"; };
-        "e2-customs" = { virtual = true; virtualType = "tap"; };
-        "e3-mgmt" = { virtual = true; virtualType = "tap"; };
-        "e4-oob" = { virtual = true; virtualType = "tap"; };
-        "e7-dcsw" = { virtual = true; virtualType = "tap"; };
-      };
       hscloud.anchorvm = {
         blkdev = "/anchor.img";
         ram = 32;
@@ -180,7 +169,7 @@
 
     customs = { config, pkgs, ... }: {
       imports = [
-        ../modules/eoip.nix
+        ../modules/gretap.nix
       ];
       environment.systemPackages = with pkgs; [
         tcpdump htop dstat file dhcpcd
@@ -194,12 +183,10 @@
       networking.defaultGateway = "185.236.240.4";
       networking.defaultGateway6 = "2a0d:eb00:2137:1::2";
       networking.interfaces."edge" = {
-        virtual = true;
-        virtualType = "tap";
         ipv4.addresses = [{ address = "185.236.240.5"; prefixLength = 31; }];
         ipv6.addresses = [{ address = "2a0d:eb00:2137:1::3"; prefixLength = 127; }];
       };
-      hscloud.eoip.interfaces."edge" = {
+      hscloud.gretap.interfaces."edge" = {
         parent = "eth2";
         localV4 = "192.168.2.1";
         remoteV4 = "192.168.2.2";
@@ -5,9 +5,9 @@
 # - customs, which simulates customs.hackerspace.pl.
 #
-# We use EoIP to build up virtual ethernet links between the machines, and
-# to run VLANs on that. We don't just use plain 'vlans' from NixOS tests as
-# we actually want to run 802.1q ourselves from the edge01 config.
+# We use GRETap to build up virtual ethernet links between the machines, and to
+# run VLANs on that. We don't just use plain 'vlans' from NixOS tests as we
+# actually want to run 802.1q ourselves from the edge01 config.
 #
 # Everything else is pretty much straightforward. Bring up everything, ping